class VotingPower:
    def __init__(self, name, voting_weight):
        self.name = name
        self.voting_weight = voting_weight
    
def main():
    print(11)
if __name__ == '__main__':
    main()