## ---------------- IntangibleAsset ---------------------- ##
from cpanlp.account.assets.intangibleasset.intangibleasset import *
from cpanlp.account.assets.intangibleasset.landuseright import *
from cpanlp.account.assets.intangibleasset.goodwill import *
from cpanlp.account.assets.intangibleasset.intellectualproperty import *
from cpanlp.account.assets.intangibleasset.franchise import *
from cpanlp.account.assets.intangibleasset.patent import *
