## ---------------- Investor ---------------------- ##
from cpanlp.person.investor.investor import *
from cpanlp.person.investor.shareholder import *
from cpanlp.person.investor.major_shareholder import *
from cpanlp.person.investor.controlling_shareholder import *
from cpanlp.person.investor.nominee_shareholder import *
from cpanlp.person.investor.consenting_investor import *